@@ -18,7 +18,7 @@ if [ ! -x "${LZIP}" ] ; then
 	exit 1
 fi
 
-if [ -d tmp ] ; then rm -r tmp ; fi
+if [ -d tmp ] ; then rm -rf tmp ; fi
 mkdir tmp
 echo -n "testing minilzip..."
 cd "${objdir}"/tmp
@@ -29,7 +29,7 @@ fail=0
 "${LZIP}" -cd "${testdir}"/COPYING.lz > copy || fail=1
 cmp in copy || fail=1
 
-for i in s4096 1 2 3 4 5 6 7 8 9; do
+for i in s4096 1 2 3 4 5 6 7 8; do
 	"${LZIP}" -k -$i in || fail=1
 	mv -f in.lz copy.lz || fail=1
 	echo -n "garbage" >> copy.lz || fail=1
@@ -38,7 +38,7 @@ for i in s4096 1 2 3 4 5 6 7 8 9; do
 	echo -n .
 done
 
-for i in s4096 1 2 3 4 5 6 7 8 9; do
+for i in s4096 1 2 3 4 5 6 7 8; do
 	"${LZIP}" -c -$i in > out || fail=1
 	echo -n "g" >> out || fail=1
 	"${LZIP}" -cd out > copy || fail=1
@@ -46,25 +46,25 @@ for i in s4096 1 2 3 4 5 6 7 8 9; do
 	echo -n .
 done
 
-for i in s4096 1 2 3 4 5 6 7 8 9; do
+for i in s4096 1 2 3 4 5 6 7 8; do
 	"${LZIP}" -c -$i < in > out || fail=1
 	"${LZIP}" -d < out > copy || fail=1
 	cmp in copy || fail=1
 	echo -n .
 done
 
-for i in s4096 1 2 3 4 5 6 7 8 9; do
+for i in s4096 1 2 3 4 5 6 7 8; do
 	"${LZIP}" -f -$i -o out < in || fail=1
 	"${LZIP}" -df -o copy < out.lz || fail=1
 	cmp in copy || fail=1
 	echo -n .
 done
 
-"${LZCHECK}" in || fail=1
+"${LZCHECK}" in 2>/dev/null || fail=1
 echo -n .
 
 echo
-if [ ${fail} = 0 ]; then
+if [ ${fail} = 0 ] ; then
 	echo "tests completed successfully."
 	cd "${objdir}" && rm -r tmp
 else
